package edu.nyu.scps.json;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.method.ScrollingMovementMethod;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.text.DateFormat;
import java.util.Locale;


public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        TextView textView = (TextView)findViewById(R.id.textView);
        textView.setHorizontallyScrolling(true);
        textView.setMovementMethod(new ScrollingMovementMethod());

        String jSONString = "{\"coord\":{\"lon\":-74.01,\"lat\":40.71},\"weather\":[{\"id\":741,\"main\":\"Fog\",\"description\":\"fog\",\"icon\":\"50d\"}],\"base\":\"cmc stations\",\"main\":{\"temp\":73.24,\"pressure\":1017,\"humidity\":88,\"temp_min\":69.8,\"temp_max\":75.2},\"wind\":{\"speed\":6.7,\"deg\":160},\"clouds\":{\"all\":75},\"dt\":1436262811,\"sys\":{\"type\":1,\"id\":2120,\"message\":0.0068,\"country\":\"US\",\"sunrise\":1436261527,\"sunset\":1436315377},\"id\":5128581,\"name\":\"New York\",\"cod\":200}";
        Log.d("myTag", jSONString);
        textView.append("jSONString =\n" + jSONString + "\n\n");
        String horizontalLine = "--------------------------------------------------------------\n\n";
        textView.append(horizontalLine);

        try {
            //Convert a String into a JSONObject.
            JSONObject jSONObject = new JSONObject(jSONString);
            Log.d("myTag", jSONObject.toString(4));
            textView.append("jSONbject =\n" + jSONObject.toString(4) + "\n\n");
            textView.append(horizontalLine);

            //Get a long field from a JSONObject.
            long seconds = jSONObject.getLong("dt"); //data receiving time, in seconds since 1970
            long milliseconds = 1000L * seconds;
            textView.append("dt = " + seconds + "\n");
            DateFormat dateFormat =
                    DateFormat.getDateTimeInstance(DateFormat.FULL, DateFormat.LONG, Locale.getDefault());
            textView.append("dt = " + dateFormat.format(milliseconds) + "\n\n");

            //Get a JSONObject field from a JSONObject.
            JSONObject main = jSONObject.getJSONObject("main");
            textView.append("main = " + main.toString(4) + "\n\n");

            //Get a double field from a JSONObject.
            double temp = main.getDouble("temp"); //temperature in fahrenheit
            textView.append("main.temp = " + temp + "\n\n");

            //Get a JSONArray field from a JSONObject.
            JSONArray weather = jSONObject.getJSONArray("weather");
            textView.append("weather = " + weather.toString(4) + "\n\n");

            for (int i = 0; i < weather.length(); ++i) {
                //Get a JSONObject element from a JSONArray.
                JSONObject condition = weather.getJSONObject(i);
                textView.append("weather[" + i + "] = " + condition.toString(4) + "\n\n");

                //Get a String field from a JSONObject.
                String conditionMain = condition.getString("main");
                String description = condition.getString("description");
                textView.append("weather[" + i + "].main = " + conditionMain + "\n");
                textView.append("weather[" + i + "].description = " + description + "\n\n");
            }
        } catch (JSONException jSONException) {
            textView.append(jSONException.toString());
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
